[Openvas-commits] r8083 - in trunk/openvas-libraries: . omp

scm-commit@wald.intevation.org scm-commit at wald.intevation.org
Fri Jun 18 18:38:26 CEST 2010


Author: mattm
Date: 2010-06-18 18:38:24 +0200 (Fri, 18 Jun 2010)
New Revision: 8083

Modified:
   trunk/openvas-libraries/ChangeLog
   trunk/openvas-libraries/omp/omp.c
   trunk/openvas-libraries/omp/omp.h
Log:
	* omp/omp.c: Replace GET_STATUS with GET_TASKS in comments.
	(omp_wait_for_task_start, omp_wait_for_task_end)
	(omp_wait_for_task_stop, omp_wait_for_task_delete): Use new name GET_TASKS
	in OMP.
	(omp_get_status): Remove.
	(omp_get_tasks): New function.  Rename from omp_get_status.

	* omp/omp.h: Update headers accordingly.

Modified: trunk/openvas-libraries/ChangeLog
===================================================================
--- trunk/openvas-libraries/ChangeLog	2010-06-18 16:20:42 UTC (rev 8082)
+++ trunk/openvas-libraries/ChangeLog	2010-06-18 16:38:24 UTC (rev 8083)
@@ -1,3 +1,14 @@
+2010-06-18  Matthew Mundell <matthew.mundell at greenbone.net>
+
+	* omp/omp.c: Replace GET_STATUS with GET_TASKS in comments.
+	(omp_wait_for_task_start, omp_wait_for_task_end)
+	(omp_wait_for_task_stop, omp_wait_for_task_delete): Use new name GET_TASKS
+	in OMP.
+	(omp_get_status): Remove.
+	(omp_get_tasks): New function.  Rename from omp_get_status.
+
+	* omp/omp.h: Update headers accordingly.
+
 2010-06-17  Felix Wolfsteller <felix.wolfsteller at greenbone.net>
 
 	* nasl/nasl_misc_funcs.c: Indented with
@@ -18,12 +29,12 @@
 	Buf Fix. Changed function names related to NTLMSSP by appending
 	_ntlmssp. This would prevent conflicts that occur while WMI and
 	NTLMSSP features co-exist.
-	
+
 	* nasl/smb_signing.c, nasl/smb_signing.h, nasl/proto.h,
 	nasl/genrand.c, nasl/nasl_crypto.c, nasl/charset.h, nasl/time.c,
 	nasl/ntlmssp.c, nasl/smb_crypt.c, nasl/smb_crypt.h, nasl/smb_crypt2.c,
 	nasl/iconv.c, nasl/md4.c, nasl/md4.h, nasl/charcnv.c, nasl/arc4.c:
-	Changed conflicting function names by appending names with _ntlmssp. 
+	Changed conflicting function names by appending names with _ntlmssp.
 
 2010-06-08  Felix Wolfsteller <felix.wolfsteller at greenbone.net>
 
@@ -234,7 +245,7 @@
 
 	* misc/ldap_auth.h (ldap_auth_info): Added field whether StartTLS is
 	mandatory, adjusted proto.
-	
+
 	* misc/ldap_auth.c (ldap_auth_info_new): Added parameter whehter
 	StartTLS is required.
 	(ldap_authenticate): Respect new configuration entry.

Modified: trunk/openvas-libraries/omp/omp.c
===================================================================
--- trunk/openvas-libraries/omp/omp.h	2010-06-18 16:20:42 UTC (rev 8082)
+++ trunk/openvas-libraries/omp/omp.h	2010-06-18 16:38:24 UTC (rev 8083)
@@ -80,7 +80,7 @@
 
 int omp_wait_for_task_delete (gnutls_session_t *, const char *);
 
-int omp_get_status (gnutls_session_t *, const char *, int, entity_t *);
+int omp_get_tasks (gnutls_session_t *, const char *, int, entity_t *);
 
 int omp_get_report (gnutls_session_t *, const char *, const char *, entity_t *);
 



More information about the Openvas-commits mailing list
--- trunk/openvas-libraries/omp/omp.c	2010-06-18 16:20:42 UTC (rev 8082)
+++ trunk/openvas-libraries/omp/omp.c	2010-06-18 16:38:24 UTC (rev 8083)
@@ -100,9 +100,9 @@
 /* OMP. */
 
 /**
  * @brief Get the task status from an OMP GET_STATUS response.
  *
- * @param[in]  response   GET_STATUS response.
+ * @param[in]  response   GET_TASKS response.
  *
  * @return The entity_text of the status entity if the entity is found, else
  *         NULL.
@@ -694,7 +694,7 @@
 {
   while (1)
     {
-      if (openvas_server_sendf (session, "<get_status/>") == -1)
+      if (openvas_server_sendf (session, "<get_tasks/>") == -1)
         return -1;
 
       /* Read the response. */
@@ -798,7 +798,7 @@
 {
   while (1)
     {
-      if (openvas_server_sendf (session, "<get_status/>") == -1)
+      if (openvas_server_sendf (session, "<get_tasks/>") == -1)
         return -1;
 
       /* Read the response. */
@@ -906,7 +906,7 @@
 {
   while (1)
     {
-      if (openvas_server_sendf (session, "<get_status/>") == -1)
+      if (openvas_server_sendf (session, "<get_tasks/>") == -1)
         return -1;
 
       /* Read the response. */
@@ -1018,7 +1018,7 @@
       const char* status;
 
       if (openvas_server_sendf (session,
-                                "<get_status task_id=\"%s\"/>",
+                                "<get_tasks task_id=\"%s\"/>",
                                 id)
           == -1)
         return -1;
@@ -1061,14 +1061,14 @@
  * @param[in]  session         Pointer to GNUTLS session.
  * @param[in]  id              ID of task or NULL for all tasks.
  * @param[in]  include_rcfile  Request rcfile in status if true.
  * @param[out] status          Status return.  On success contains GET_STATUS
  *                             response.
  *
  * @return 0 on success, -1 or OMP response code on error.
  */
 int
-omp_get_status (gnutls_session_t* session, const char* id, int include_rcfile,
-                entity_t* status)
+omp_get_tasks (gnutls_session_t* session, const char* id, int include_rcfile,
+               entity_t* status)
 {
   const char* status_code;
   int ret;
@@ -1076,7 +1076,7 @@
   if (id == NULL)
     {
       if (openvas_server_sendf (session,
-                                "<get_status rcfile=\"%i\"/>",
+                                "<get_tasks rcfile=\"%i\"/>",
                                 include_rcfile)
           == -1)
         return -1;
@@ -1084,7 +1084,7 @@
   else
     {
       if (openvas_server_sendf (session,
-                                "<get_status task_id=\"%s\" rcfile=\"%i\"/>",
+                                "<get_tasks task_id=\"%s\" rcfile=\"%i\"/>",
                                 id,
                                 include_rcfile)
           == -1)
@@ -1802,7 +1802,7 @@
  *
  * @param[in]  session         Pointer to GNUTLS session.
  * @param[in]  oid             OID of NVT or NULL for all NVTs.
  * @param[out] response        Status return. On success contains GET_STATUS
  *                             response.
  *
  * @return 0 on success, -1 on error.
@@ -100,9 +100,9 @@
 
 /**
- * @brief Get the task status from an OMP GET_STATUS response.
+ * @brief Get the task status from an OMP GET_TASKS response.
  *
@@ -1061,14 +1061,14 @@
  * @param[in]  id              ID of task or NULL for all tasks.
  * @param[in]  include_rcfile  Request rcfile in status if true.
- * @param[out] status          Status return.  On success contains GET_STATUS
+ * @param[out] status          Status return.  On success contains GET_TASKS
  *                             response.
  *
@@ -1802,7 +1802,7 @@
  * @param[in]  session         Pointer to GNUTLS session.
  * @param[in]  oid             OID of NVT or NULL for all NVTs.
- * @param[out] response        Status return. On success contains GET_STATUS
+ * @param[out] response        Status return. On success contains GET_TASKS
  *                             response.
  *

Modified: trunk/openvas-libraries/omp/omp.h
===================================================================